#!/bin/bash

# Modify this to change the default if you don't want to use the
# optional argument. E.g: scale=${1:-1.25} for 1.25x scaling.
scale=${1:-1.5}

echo "Running $(basename $0)"

xdg=$(echo $XDG_SESSION_TYPE)
if [ $xdg != "x11" ]; then
    echo "ERROR: Running $xdg display server rather than x11"
    exit 1
fi

xrandr=$(xrandr -q)  # Get current screen properties

# Get the current panning value (i.e. up/down scaled resolution):
currentPan=$(xrandr |
             grep -o "current[^,]\+" |  # Get "current [pan]" section
             cut -c8- |                 # Remove "current" (first 8 chars)
             tr -d "[:space:]")         # Remove all whitespace

# 设备支持的最佳分辨率:
res=$("xrandr" |
      sed -n '/^ /p' | head -n 1 | #空格开头列出所有，再取第一个分辨率
      xargs |          
      grep -o '^\S*') #只保留空格前的值

# Get display identifier:
display=$("xrandr" |
      sed '/ connected primary/!d' | #为了拿到显示器名称
      grep -o '^\S*') 

xRes=$(echo $res | cut -d "x" -f 1)
yRes=$(echo $res | cut -d "x" -f 2)
xPan=$(echo "scale=0;($xRes*$scale)/1" | bc)
yPan=$(echo "scale=0;($yRes*$scale)/1" | bc)
pan=$xPan'x'$yPan
scale=$scale'x'$scale  # Change scale from "1.5" to "1.5x1.5"

echo "Intended scaling:           $scale"
echo "Display identifier:         $display"
echo "Max hardware resolution:    $res"
echo "Current panning resolution: $currentPan"
echo "New panning resolution:     $pan"

if [ "$currentPan" != "$pan" ]; then
    xrandr --output $display --scale $scale --panning $pan
else
    echo "Not changing scaling as current and intended resolutions match."
fi
